@echo off

::
:: Copyright (c) 2011-2012 EBM WebSourcing, 2012-2013 Linagora
::
:: This program/library is free software: you can redistribute it and/or modify
:: it under the terms of the GNU Lesser General Public License as published by
:: the Free Software Foundation, either version 2.1 of the License, or (at your
:: option) any later version.
::
:: This program/library is distributed in the hope that it will be useful, but
:: WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
:: FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
:: for more details.
::
:: You should have received a copy of the GNU Lesser General Public License
:: along with this program/library; If not, see <http://www.gnu.org/licenses/>
:: for the GNU Lesser General Public License version 2.1.
::
:: --------------------------------------------------------------------------------
::
::                   Petals ESB - Bootstrap script
::
:: Environment variables:
::
::     JAVA_HOME   			Home directory of the JVM to be used
::
::     PETALS_JAVA_OPTS 	Options for the JVM. Try "java -h" to get informations
::                 			about the available options for your environment
::
:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::

:: Get the content of variables at runtime and not at parse time
:: %var% = parse time
:: !var! = run time
setlocal EnableDelayedExpansion 

:: The Java executable
if not defined JAVA_HOME (
   set JAVA=java
) else (
   set JAVA="%JAVA_HOME%\bin\java.exe"
)

:: The Petals home
if not defined PETALS_HOME (
   set PETALS_HOME="%CD%\.."
)

if not exist %PETALS_HOME% (
   echo PETALS_HOME is not valid: %PETALS_HOME%
   goto :EOF
)

:: Keep the Petals home without any quote
set RAW_PETALS_HOME=%PETALS_HOME:"=%
set RAW_PETALS_LIB_DIR=%RAW_PETALS_HOME%\lib
set RAW_PETALS_EXT_DIR=%RAW_PETALS_HOME%\extensions

:: The Petals bootstrap
set PETALS_BOOTSTRAP_JAR_NAME=petals-launcher-default.jar
set PETALS_JAR="%RAW_PETALS_LIB_DIR%\%PETALS_BOOTSTRAP_JAR_NAME%"
if not exist %PETALS_JAR% (
   echo ERROR: %PETALS_BOOTSTRAP_JAR_NAME%: JAR archive not found
   goto :EOF
)

:: Logs
if not defined PETALS_CLASSPATH (

   :: Find the log extensions
   set /a count=0
   for %%a in ("%RAW_PETALS_LIB_DIR%\petals-log-*.jar") do (
      set /a count+=1
	  if not defined PETALS_LOG_ARTIFACT (
		 set PETALS_LOG_ARTIFACT=%%a
	  )
   )

   :: Check that the JAR is defined only once in %PETALS_HOME%
   if !count!==0 (
      echo ERROR: Petals Log Handler not found in %RAW_PETALS_LIB_DIR%
      goto :EOF
   )
   
   if !count! gtr 1 (
	  echo ERROR: Several Petals Log Handler versions were found in %RAW_PETALS_LIB_DIR%: !PETALS_LOG_ARTIFACT!
      goto :EOF
   )
    
   set PETALS_CLASSPATH="!PETALS_LOG_ARTIFACT!"
)

:: Add the conf directory to the classpath to provide the default server configuration
set PETALS_CLASSPATH=%PETALS_CLASSPATH%;"%RAW_PETALS_HOME%\conf"

:: Petals options
set PETALS_OPTS=-Dpetals.lib.dir="%RAW_PETALS_LIB_DIR%" -Dpetals.ext.dir="%RAW_PETALS_EXT_DIR%"

:: Saxon is our XSLT engine
set PETALS_OPTS=%PETALS_OPTS% -Djavax.xml.transform.TransformerFactory=net.sf.saxon.TransformerFactoryImpl

set ENV_FILE="%RAW_PETALS_HOME%/conf/env.bat"
if exist %ENV_FILE% (
	call %ENV_FILE%
)

:: Start
start "OW2 :: Petals Enterprise Service Bus" %JAVA% -classpath %PETALS_CLASSPATH%;%PETALS_JAR% %PETALS_JAVA_OPTS% %PETALS_OPTS% org.ow2.petals.launcher.PetalsLauncher
