#!/bin/sh
#
# Copyright (c) 2011-2012 EBM WebSourcing, 2012-2013 Linagora
#
# This program/library is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 2.1 of the License, or (at your
# option) any later version.
#
# This program/library is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
# for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program/library; If not, see <http://www.gnu.org/licenses/>
# for the GNU Lesser General Public License version 2.1.
#
#############################################################################
#
#                      Petals ESB Bootstrap Script
#
# Environment variables:
#
#	JAVA_HOME			Directory containing the JRE. Use the java executable
#						found in $PATH if not defined.
#
#	PETALS_JAVA_OPTS	Options for the JVM. Try "java -h" to get informations
#						about the available options for your environment
#
#############################################################################

ABSOLUTE_PATH_SCRIPT=`readlink -f "$0"`
DIRNAME=`dirname "$ABSOLUTE_PATH_SCRIPT"`

# Set the path to the java executable
JAVA="$JAVA_HOME/bin/java"
[ -x "$JAVA" ] || JAVA="`which java`" || {
	echo "ERROR: java executable not found" >&2
	exit 1
}

PETALS_LIB_DIR="$DIRNAME/../lib"
PETALS_EXT_DIR="$DIRNAME/../extensions"

# Set the path to petals bootstrap jar
PETALS_BOOTSTRAP_JAR_NAME="petals-launcher-default.jar"
PETALS_JAR="$PETALS_LIB_DIR/$PETALS_BOOTSTRAP_JAR_NAME"
[ -f "$PETALS_JAR" ] || {
	echo "ERROR: $PETALS_BOOTSTRAP_JAR_NAME: JAR archive not found" >&2
	exit 1
}


# Adapt pathes if architecture is Cygwin
case "`uname`" in
	CYGWIN*)
		JAVA="`cygpath --unix "$JAVA"`"
		PETALS_LIB_DIR="`cygpath --dos "$PETALS_LIB_DIR"`"
		PETALS_JAR="`cygpath --unix "$PETALS_JAR"`"
		;;
esac

# Logs
if [ -z "$PETALS_CLASSPATH" ]; then
   PETALS_LOG_ARTIFACT=`ls -1 $PETALS_LIB_DIR/petals-log-*.jar 2>/dev/null`
   # Check that the JAR is defined only once
   if [ -z "$PETALS_LOG_ARTIFACT" ]; then
      echo "ERROR: Petals Log Handler not found in $PETALS_HOME/lib"
      exit 1
   fi;
   if [ `echo $PETALS_LOG_ARTIFACT | wc -l` -ne 1 ]; then
      echo "ERROR: Several Petals Log Handler versions were found in $PETALS_LIB_DIR: $PETALS_LOG_ARTIFACT"
      exit 1
   fi
   
   PETALS_CLASSPATH="-classpath $PETALS_LOG_ARTIFACT"
fi

# 

# Add the conf directory to the classpath to provide the default server configuration
PETALS_CLASSPATH="$PETALS_CLASSPATH:$DIRNAME/../conf"

# Petals options
PETALS_OPTS="-Dpetals.lib.dir=$PETALS_LIB_DIR -Dpetals.ext.dir=$PETALS_EXT_DIR"
# Saxon is our XSLT engine
PETALS_OPTS="$PETALS_OPTS -Djavax.xml.transform.TransformerFactory=net.sf.saxon.TransformerFactoryImpl"

ENV_FILE="$DIRNAME/../conf/env.sh"
if [ -f "$ENV_FILE" ]; then
	. $ENV_FILE
fi

# Start
exec "$JAVA" $PETALS_CLASSPATH:$PETALS_JAR $PETALS_JAVA_OPTS $PETALS_OPTS org.ow2.petals.launcher.PetalsLauncher "$@"
